[kaffe] CVS kaffe (robilad): Resynced with GNU Classpath: mark's date format fixlet

Kaffe CVS cvs-commits at kaffe.org
Mon Feb 21 14:54:44 PST 2005


PatchSet 5585 
Date: 2005/02/21 22:49:05
Author: robilad
Branch: HEAD
Tag: (none) 
Log:
Resynced with GNU Classpath: mark's date format fixlet

2005-02-20  Dalibor Topic  <robilad at kaffe.org>

        Resynced with GNU Classpath.

        2005-02-20  Mark Wielaard  <mark at klomp.org>

        * java/text/SimpleDateFormat.java
        (SimpleDateFormat(String, DateFormatSymbols)): Throw
        NullPointerException when formatData is null.

Members: 
	ChangeLog:1.3629->1.3630 
	libraries/javalib/java/text/SimpleDateFormat.java:1.46->1.47 

Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.3629 kaffe/ChangeLog:1.3630
--- kaffe/ChangeLog:1.3629	Mon Feb 21 22:41:59 2005
+++ kaffe/ChangeLog	Mon Feb 21 22:49:05 2005
@@ -2,6 +2,16 @@
 
 	Resynced with GNU Classpath.
 
+	2005-02-20  Mark Wielaard  <mark at klomp.org>
+
+        * java/text/SimpleDateFormat.java
+        (SimpleDateFormat(String, DateFormatSymbols)): Throw
+        NullPointerException when formatData is null.
+
+2005-02-20  Dalibor Topic  <robilad at kaffe.org>
+
+	Resynced with GNU Classpath.
+
 	2005-02-19  Archie Cobbs  <archie at dellroad.org>
 
         * java/lang/Throwable.java: simplify initializing cause in constructor
Index: kaffe/libraries/javalib/java/text/SimpleDateFormat.java
diff -u kaffe/libraries/javalib/java/text/SimpleDateFormat.java:1.46 kaffe/libraries/javalib/java/text/SimpleDateFormat.java:1.47
--- kaffe/libraries/javalib/java/text/SimpleDateFormat.java:1.46	Fri Feb 18 11:26:34 2005
+++ kaffe/libraries/javalib/java/text/SimpleDateFormat.java	Mon Feb 21 22:49:08 2005
@@ -430,7 +430,7 @@
    *
    * @param pattern the non-localized pattern to use.
    * @param formatData the formatting symbols to use.
    * @throws NullPointerException if the pattern is null.
    * @throws IllegalArgumentException if the pattern is invalid.
    */
   public SimpleDateFormat(String pattern, DateFormatSymbols formatData)
@@ -439,6 +439,8 @@
     calendar = new GregorianCalendar();
     computeCenturyStart ();
     tokens = new ArrayList();
+    if (formatData == null)
+      throw new NullPointerException("formatData");
     this.formatData = formatData;
     compileFormat(pattern);
     this.pattern = pattern;
@@ -430,7 +430,7 @@
    * @param pattern the non-localized pattern to use.
    * @param formatData the formatting symbols to use.
-   * @throws NullPointerException if the pattern is null.
+   * @throws NullPointerException if the pattern or formatData is null.
    * @throws IllegalArgumentException if the pattern is invalid.
    */




More information about the kaffe mailing list